"""Generated client library for networkmanagement version v1."""
# NOTE: This file is autogenerated and should not be edited by hand.

from apitools.base.py import base_api
from googlecloudsdk.generated_clients.apis.networkmanagement.v1 import networkmanagement_v1_messages as messages


class NetworkmanagementV1(base_api.BaseApiClient):
  """Generated client library for service networkmanagement version v1."""

  MESSAGES_MODULE = messages
  BASE_URL = 'https://networkmanagement.googleapis.com/'
  MTLS_BASE_URL = 'https://networkmanagement.mtls.googleapis.com/'

  _PACKAGE = 'networkmanagement'
  _SCOPES = ['https://www.googleapis.com/auth/cloud-platform']
  _VERSION = 'v1'
  _CLIENT_ID = 'CLIENT_ID'
  _CLIENT_SECRET = 'CLIENT_SECRET'
  _USER_AGENT = 'google-cloud-sdk'
  _CLIENT_CLASS_NAME = 'NetworkmanagementV1'
  _URL_VERSION = 'v1'
  _API_KEY = None

  def __init__(self, url='', credentials=None,
               get_credentials=True, http=None, model=None,
               log_request=False, log_response=False,
               credentials_args=None, default_global_params=None,
               additional_http_headers=None, response_encoding=None):
    """Create a new networkmanagement handle."""
    url = url or self.BASE_URL
    super(NetworkmanagementV1, self).__init__(
        url, credentials=credentials,
        get_credentials=get_credentials, http=http, model=model,
        log_request=log_request, log_response=log_response,
        credentials_args=credentials_args,
        default_global_params=default_global_params,
        additional_http_headers=additional_http_headers,
        response_encoding=response_encoding)
    self.organizations_locations_global_operations = self.OrganizationsLocationsGlobalOperationsService(self)
    self.organizations_locations_global = self.OrganizationsLocationsGlobalService(self)
    self.organizations_locations_vpcFlowLogsConfigs = self.OrganizationsLocationsVpcFlowLogsConfigsService(self)
    self.organizations_locations = self.OrganizationsLocationsService(self)
    self.organizations = self.OrganizationsService(self)
    self.projects_locations_global_connectivityTests = self.ProjectsLocationsGlobalConnectivityTestsService(self)
    self.projects_locations_global_operations = self.ProjectsLocationsGlobalOperationsService(self)
    self.projects_locations_global = self.ProjectsLocationsGlobalService(self)
    self.projects_locations_networkMonitoringProviders_monitoringPoints = self.ProjectsLocationsNetworkMonitoringProvidersMonitoringPointsService(self)
    self.projects_locations_networkMonitoringProviders_networkPaths = self.ProjectsLocationsNetworkMonitoringProvidersNetworkPathsService(self)
    self.projects_locations_networkMonitoringProviders_webPaths = self.ProjectsLocationsNetworkMonitoringProvidersWebPathsService(self)
    self.projects_locations_networkMonitoringProviders = self.ProjectsLocationsNetworkMonitoringProvidersService(self)
    self.projects_locations_vpcFlowLogsConfigs = self.ProjectsLocationsVpcFlowLogsConfigsService(self)
    self.projects_locations = self.ProjectsLocationsService(self)
    self.projects = self.ProjectsService(self)

  class OrganizationsLocationsGlobalOperationsService(base_api.BaseApiService):
    """Service class for the organizations_locations_global_operations resource."""

    _NAME = 'organizations_locations_global_operations'

    def __init__(self, client):
      super(NetworkmanagementV1.OrganizationsLocationsGlobalOperationsService, self).__init__(client)
      self._upload_configs = {
          }

    def Cancel(self, request, global_params=None):
      r"""Starts asynchronous cancellation on a long-running operation. The server makes a best effort to cancel the operation, but success is not guaranteed. If the server doesn't support this method, it returns `google.rpc.Code.UNIMPLEMENTED`. Clients can use Operations.GetOperation or other methods to check whether the cancellation succeeded or whether the operation completed despite cancellation. On successful cancellation, the operation is not deleted; instead, it becomes an operation with an Operation.error value with a google.rpc.Status.code of `1`, corresponding to `Code.CANCELLED`.

      Args:
        request: (NetworkmanagementOrganizationsLocationsGlobalOperationsCancelRequest) input message
        global_params: (StandardQueryParameters, default: None) global arguments
      Returns:
        (Empty) The response message.
      """
      config = self.GetMethodConfig('Cancel')
      return self._RunMethod(
          config, request, global_params=global_params)

    Cancel.method_config = lambda: base_api.ApiMethodInfo(
        flat_path='v1/organizations/{organizationsId}/locations/global/operations/{operationsId}:cancel',
        http_method='POST',
        method_id='networkmanagement.organizations.locations.global.operations.cancel',
        ordered_params=['name'],
        path_params=['name'],
        query_params=[],
        relative_path='v1/{+name}:cancel',
        request_field='cancelOperationRequest',
        request_type_name='NetworkmanagementOrganizationsLocationsGlobalOperationsCancelRequest',
        response_type_name='Empty',
        supports_download=False,
    )

    def Delete(self, request, global_params=None):
      r"""Deletes a long-running operation. This method indicates that the client is no longer interested in the operation result. It does not cancel the operation. If the server doesn't support this method, it returns `google.rpc.Code.UNIMPLEMENTED`.

      Args:
        request: (NetworkmanagementOrganizationsLocationsGlobalOperationsDeleteRequest) input message
        global_params: (StandardQueryParameters, default: None) global arguments
      Returns:
        (Empty) The response message.
      """
      config = self.GetMethodConfig('Delete')
      return self._RunMethod(
          config, request, global_params=global_params)

    Delete.method_config = lambda: base_api.ApiMethodInfo(
        flat_path='v1/organizations/{organizationsId}/locations/global/operations/{operationsId}',
        http_method='DELETE',
        method_id='networkmanagement.organizations.locations.global.operations.delete',
        ordered_params=['name'],
        path_params=['name'],
        query_params=[],
        relative_path='v1/{+name}',
        request_field='',
        request_type_name='NetworkmanagementOrganizationsLocationsGlobalOperationsDeleteRequest',
        response_type_name='Empty',
        supports_download=False,
    )

    def Get(self, request, global_params=None):
      r"""Gets the latest state of a long-running operation. Clients can use this method to poll the operation result at intervals as recommended by the API service.

      Args:
        request: (NetworkmanagementOrganizationsLocationsGlobalOperationsGetRequest) input message
        global_params: (StandardQueryParameters, default: None) global arguments
      Returns:
        (Operation) The response message.
      """
      config = self.GetMethodConfig('Get')
      return self._RunMethod(
          config, request, global_params=global_params)

    Get.method_config = lambda: base_api.ApiMethodInfo(
        flat_path='v1/organizations/{organizationsId}/locations/global/operations/{operationsId}',
        http_method='GET',
        method_id='networkmanagement.organizations.locations.global.operations.get',
        ordered_params=['name'],
        path_params=['name'],
        query_params=[],
        relative_path='v1/{+name}',
        request_field='',
        request_type_name='NetworkmanagementOrganizationsLocationsGlobalOperationsGetRequest',
        response_type_name='Operation',
        supports_download=False,
    )

    def List(self, request, global_params=None):
      r"""Lists operations that match the specified filter in the request. If the server doesn't support this method, it returns `UNIMPLEMENTED`.

      Args:
        request: (NetworkmanagementOrganizationsLocationsGlobalOperationsListRequest) input message
        global_params: (StandardQueryParameters, default: None) global arguments
      Returns:
        (ListOperationsResponse) The response message.
      """
      config = self.GetMethodConfig('List')
      return self._RunMethod(
          config, request, global_params=global_params)

    List.method_config = lambda: base_api.ApiMethodInfo(
        flat_path='v1/organizations/{organizationsId}/locations/global/operations',
        http_method='GET',
        method_id='networkmanagement.organizations.locations.global.operations.list',
        ordered_params=['name'],
        path_params=['name'],
        query_params=['filter', 'pageSize', 'pageToken', 'returnPartialSuccess'],
        relative_path='v1/{+name}/operations',
        request_field='',
        request_type_name='NetworkmanagementOrganizationsLocationsGlobalOperationsListRequest',
        response_type_name='ListOperationsResponse',
        supports_download=False,
    )

  class OrganizationsLocationsGlobalService(base_api.BaseApiService):
    """Service class for the organizations_locations_global resource."""

    _NAME = 'organizations_locations_global'

    def __init__(self, client):
      super(NetworkmanagementV1.OrganizationsLocationsGlobalService, self).__init__(client)
      self._upload_configs = {
          }

  class OrganizationsLocationsVpcFlowLogsConfigsService(base_api.BaseApiService):
    """Service class for the organizations_locations_vpcFlowLogsConfigs resource."""

    _NAME = 'organizations_locations_vpcFlowLogsConfigs'

    def __init__(self, client):
      super(NetworkmanagementV1.OrganizationsLocationsVpcFlowLogsConfigsService, self).__init__(client)
      self._upload_configs = {
          }

    def Create(self, request, global_params=None):
      r"""Creates a new `VpcFlowLogsConfig`. If a configuration with the exact same settings already exists (even if the ID is different), the creation fails. Notes: 1. Creating a configuration with `state=DISABLED` will fail 2. The following fields are not considered as settings for the purpose of the check mentioned above, therefore - creating another configuration with the same fields but different values for the following fields will fail as well: * name * create_time * update_time * labels * description.

      Args:
        request: (NetworkmanagementOrganizationsLocationsVpcFlowLogsConfigsCreateRequest) input message
        global_params: (StandardQueryParameters, default: None) global arguments
      Returns:
        (Operation) The response message.
      """
      config = self.GetMethodConfig('Create')
      return self._RunMethod(
          config, request, global_params=global_params)

    Create.method_config = lambda: base_api.ApiMethodInfo(
        flat_path='v1/organizations/{organizationsId}/locations/{locationsId}/vpcFlowLogsConfigs',
        http_method='POST',
        method_id='networkmanagement.organizations.locations.vpcFlowLogsConfigs.create',
        ordered_params=['parent'],
        path_params=['parent'],
        query_params=['vpcFlowLogsConfigId'],
        relative_path='v1/{+parent}/vpcFlowLogsConfigs',
        request_field='vpcFlowLogsConfig',
        request_type_name='NetworkmanagementOrganizationsLocationsVpcFlowLogsConfigsCreateRequest',
        response_type_name='Operation',
        supports_download=False,
    )

    def Delete(self, request, global_params=None):
      r"""Deletes a specific `VpcFlowLogsConfig`.

      Args:
        request: (NetworkmanagementOrganizationsLocationsVpcFlowLogsConfigsDeleteRequest) input message
        global_params: (StandardQueryParameters, default: None) global arguments
      Returns:
        (Operation) The response message.
      """
      config = self.GetMethodConfig('Delete')
      return self._RunMethod(
          config, request, global_params=global_params)

    Delete.method_config = lambda: base_api.ApiMethodInfo(
        flat_path='v1/organizations/{organizationsId}/locations/{locationsId}/vpcFlowLogsConfigs/{vpcFlowLogsConfigsId}',
        http_method='DELETE',
        method_id='networkmanagement.organizations.locations.vpcFlowLogsConfigs.delete',
        ordered_params=['name'],
        path_params=['name'],
        query_params=[],
        relative_path='v1/{+name}',
        request_field='',
        request_type_name='NetworkmanagementOrganizationsLocationsVpcFlowLogsConfigsDeleteRequest',
        response_type_name='Operation',
        supports_download=False,
    )

    def Get(self, request, global_params=None):
      r"""Gets the details of a specific `VpcFlowLogsConfig`.

      Args:
        request: (NetworkmanagementOrganizationsLocationsVpcFlowLogsConfigsGetRequest) input message
        global_params: (StandardQueryParameters, default: None) global arguments
      Returns:
        (VpcFlowLogsConfig) The response message.
      """
      config = self.GetMethodConfig('Get')
      return self._RunMethod(
          config, request, global_params=global_params)

    Get.method_config = lambda: base_api.ApiMethodInfo(
        flat_path='v1/organizations/{organizationsId}/locations/{locationsId}/vpcFlowLogsConfigs/{vpcFlowLogsConfigsId}',
        http_method='GET',
        method_id='networkmanagement.organizations.locations.vpcFlowLogsConfigs.get',
        ordered_params=['name'],
        path_params=['name'],
        query_params=[],
        relative_path='v1/{+name}',
        request_field='',
        request_type_name='NetworkmanagementOrganizationsLocationsVpcFlowLogsConfigsGetRequest',
        response_type_name='VpcFlowLogsConfig',
        supports_download=False,
    )

    def List(self, request, global_params=None):
      r"""Lists all `VpcFlowLogsConfigs` in a given organization.

      Args:
        request: (NetworkmanagementOrganizationsLocationsVpcFlowLogsConfigsListRequest) input message
        global_params: (StandardQueryParameters, default: None) global arguments
      Returns:
        (ListVpcFlowLogsConfigsResponse) The response message.
      """
      config = self.GetMethodConfig('List')
      return self._RunMethod(
          config, request, global_params=global_params)

    List.method_config = lambda: base_api.ApiMethodInfo(
        flat_path='v1/organizations/{organizationsId}/locations/{locationsId}/vpcFlowLogsConfigs',
        http_method='GET',
        method_id='networkmanagement.organizations.locations.vpcFlowLogsConfigs.list',
        ordered_params=['parent'],
        path_params=['parent'],
        query_params=['filter', 'orderBy', 'pageSize', 'pageToken'],
        relative_path='v1/{+parent}/vpcFlowLogsConfigs',
        request_field='',
        request_type_name='NetworkmanagementOrganizationsLocationsVpcFlowLogsConfigsListRequest',
        response_type_name='ListVpcFlowLogsConfigsResponse',
        supports_download=False,
    )

    def Patch(self, request, global_params=None):
      r"""Updates an existing `VpcFlowLogsConfig`. If a configuration with the exact same settings already exists (even if the ID is different), the creation fails. Notes: 1. Updating a configuration with `state=DISABLED` will fail 2. The following fields are not considered as settings for the purpose of the check mentioned above, therefore - updating another configuration with the same fields but different values for the following fields will fail as well: * name * create_time * update_time * labels * description.

      Args:
        request: (NetworkmanagementOrganizationsLocationsVpcFlowLogsConfigsPatchRequest) input message
        global_params: (StandardQueryParameters, default: None) global arguments
      Returns:
        (Operation) The response message.
      """
      config = self.GetMethodConfig('Patch')
      return self._RunMethod(
          config, request, global_params=global_params)

    Patch.method_config = lambda: base_api.ApiMethodInfo(
        flat_path='v1/organizations/{organizationsId}/locations/{locationsId}/vpcFlowLogsConfigs/{vpcFlowLogsConfigsId}',
        http_method='PATCH',
        method_id='networkmanagement.organizations.locations.vpcFlowLogsConfigs.patch',
        ordered_params=['name'],
        path_params=['name'],
        query_params=['updateMask'],
        relative_path='v1/{+name}',
        request_field='vpcFlowLogsConfig',
        request_type_name='NetworkmanagementOrganizationsLocationsVpcFlowLogsConfigsPatchRequest',
        response_type_name='Operation',
        supports_download=False,
    )

  class OrganizationsLocationsService(base_api.BaseApiService):
    """Service class for the organizations_locations resource."""

    _NAME = 'organizations_locations'

    def __init__(self, client):
      super(NetworkmanagementV1.OrganizationsLocationsService, self).__init__(client)
      self._upload_configs = {
          }

    def Get(self, request, global_params=None):
      r"""Gets information about a location.

      Args:
        request: (NetworkmanagementOrganizationsLocationsGetRequest) input message
        global_params: (StandardQueryParameters, default: None) global arguments
      Returns:
        (Location) The response message.
      """
      config = self.GetMethodConfig('Get')
      return self._RunMethod(
          config, request, global_params=global_params)

    Get.method_config = lambda: base_api.ApiMethodInfo(
        flat_path='v1/organizations/{organizationsId}/locations/{locationsId}',
        http_method='GET',
        method_id='networkmanagement.organizations.locations.get',
        ordered_params=['name'],
        path_params=['name'],
        query_params=[],
        relative_path='v1/{+name}',
        request_field='',
        request_type_name='NetworkmanagementOrganizationsLocationsGetRequest',
        response_type_name='Location',
        supports_download=False,
    )

    def List(self, request, global_params=None):
      r"""Lists information about the supported locations for this service. This method lists locations based on the resource scope provided in the ListLocationsRequest.name field: * **Global locations**: If `name` is empty, the method lists the public locations available to all projects. * **Project-specific locations**: If `name` follows the format `projects/{project}`, the method lists locations visible to that specific project. This includes public, private, or other project-specific locations enabled for the project. For gRPC and client library implementations, the resource name is passed as the `name` field. For direct service calls, the resource name is incorporated into the request path based on the specific service implementation and version.

      Args:
        request: (NetworkmanagementOrganizationsLocationsListRequest) input message
        global_params: (StandardQueryParameters, default: None) global arguments
      Returns:
        (ListLocationsResponse) The response message.
      """
      config = self.GetMethodConfig('List')
      return self._RunMethod(
          config, request, global_params=global_params)

    List.method_config = lambda: base_api.ApiMethodInfo(
        flat_path='v1/organizations/{organizationsId}/locations',
        http_method='GET',
        method_id='networkmanagement.organizations.locations.list',
        ordered_params=['name'],
        path_params=['name'],
        query_params=['extraLocationTypes', 'filter', 'pageSize', 'pageToken'],
        relative_path='v1/{+name}/locations',
        request_field='',
        request_type_name='NetworkmanagementOrganizationsLocationsListRequest',
        response_type_name='ListLocationsResponse',
        supports_download=False,
    )

  class OrganizationsService(base_api.BaseApiService):
    """Service class for the organizations resource."""

    _NAME = 'organizations'

    def __init__(self, client):
      super(NetworkmanagementV1.OrganizationsService, self).__init__(client)
      self._upload_configs = {
          }

  class ProjectsLocationsGlobalConnectivityTestsService(base_api.BaseApiService):
    """Service class for the projects_locations_global_connectivityTests resource."""

    _NAME = 'projects_locations_global_connectivityTests'

    def __init__(self, client):
      super(NetworkmanagementV1.ProjectsLocationsGlobalConnectivityTestsService, self).__init__(client)
      self._upload_configs = {
          }

    def Create(self, request, global_params=None):
      r"""Creates a new Connectivity Test. After you create a test, the reachability analysis is performed as part of the long running operation, which completes when the analysis completes. If the endpoint specifications in `ConnectivityTest` are invalid (for example, containing non-existent resources in the network, or you don't have read permissions to the network configurations of listed projects), then the reachability result returns a value of `UNKNOWN`. If the endpoint specifications in `ConnectivityTest` are incomplete, the reachability result returns a value of AMBIGUOUS. For more information, see the Connectivity Test documentation.

      Args:
        request: (NetworkmanagementProjectsLocationsGlobalConnectivityTestsCreateRequest) input message
        global_params: (StandardQueryParameters, default: None) global arguments
      Returns:
        (Operation) The response message.
      """
      config = self.GetMethodConfig('Create')
      return self._RunMethod(
          config, request, global_params=global_params)

    Create.method_config = lambda: base_api.ApiMethodInfo(
        flat_path='v1/projects/{projectsId}/locations/global/connectivityTests',
        http_method='POST',
        method_id='networkmanagement.projects.locations.global.connectivityTests.create',
        ordered_params=['parent'],
        path_params=['parent'],
        query_params=['testId'],
        relative_path='v1/{+parent}/connectivityTests',
        request_field='connectivityTest',
        request_type_name='NetworkmanagementProjectsLocationsGlobalConnectivityTestsCreateRequest',
        response_type_name='Operation',
        supports_download=False,
    )

    def Delete(self, request, global_params=None):
      r"""Deletes a specific `ConnectivityTest`.

      Args:
        request: (NetworkmanagementProjectsLocationsGlobalConnectivityTestsDeleteRequest) input message
        global_params: (StandardQueryParameters, default: None) global arguments
      Returns:
        (Operation) The response message.
      """
      config = self.GetMethodConfig('Delete')
      return self._RunMethod(
          config, request, global_params=global_params)

    Delete.method_config = lambda: base_api.ApiMethodInfo(
        flat_path='v1/projects/{projectsId}/locations/global/connectivityTests/{connectivityTestsId}',
        http_method='DELETE',
        method_id='networkmanagement.projects.locations.global.connectivityTests.delete',
        ordered_params=['name'],
        path_params=['name'],
        query_params=[],
        relative_path='v1/{+name}',
        request_field='',
        request_type_name='NetworkmanagementProjectsLocationsGlobalConnectivityTestsDeleteRequest',
        response_type_name='Operation',
        supports_download=False,
    )

    def Get(self, request, global_params=None):
      r"""Gets the details of a specific Connectivity Test.

      Args:
        request: (NetworkmanagementProjectsLocationsGlobalConnectivityTestsGetRequest) input message
        global_params: (StandardQueryParameters, default: None) global arguments
      Returns:
        (ConnectivityTest) The response message.
      """
      config = self.GetMethodConfig('Get')
      return self._RunMethod(
          config, request, global_params=global_params)

    Get.method_config = lambda: base_api.ApiMethodInfo(
        flat_path='v1/projects/{projectsId}/locations/global/connectivityTests/{connectivityTestsId}',
        http_method='GET',
        method_id='networkmanagement.projects.locations.global.connectivityTests.get',
        ordered_params=['name'],
        path_params=['name'],
        query_params=[],
        relative_path='v1/{+name}',
        request_field='',
        request_type_name='NetworkmanagementProjectsLocationsGlobalConnectivityTestsGetRequest',
        response_type_name='ConnectivityTest',
        supports_download=False,
    )

    def GetIamPolicy(self, request, global_params=None):
      r"""Gets the access control policy for a resource. Returns an empty policy if the resource exists and does not have a policy set.

      Args:
        request: (NetworkmanagementProjectsLocationsGlobalConnectivityTestsGetIamPolicyRequest) input message
        global_params: (StandardQueryParameters, default: None) global arguments
      Returns:
        (Policy) The response message.
      """
      config = self.GetMethodConfig('GetIamPolicy')
      return self._RunMethod(
          config, request, global_params=global_params)

    GetIamPolicy.method_config = lambda: base_api.ApiMethodInfo(
        flat_path='v1/projects/{projectsId}/locations/global/connectivityTests/{connectivityTestsId}:getIamPolicy',
        http_method='GET',
        method_id='networkmanagement.projects.locations.global.connectivityTests.getIamPolicy',
        ordered_params=['resource'],
        path_params=['resource'],
        query_params=['options_requestedPolicyVersion'],
        relative_path='v1/{+resource}:getIamPolicy',
        request_field='',
        request_type_name='NetworkmanagementProjectsLocationsGlobalConnectivityTestsGetIamPolicyRequest',
        response_type_name='Policy',
        supports_download=False,
    )

    def List(self, request, global_params=None):
      r"""Lists all Connectivity Tests owned by a project.

      Args:
        request: (NetworkmanagementProjectsLocationsGlobalConnectivityTestsListRequest) input message
        global_params: (StandardQueryParameters, default: None) global arguments
      Returns:
        (ListConnectivityTestsResponse) The response message.
      """
      config = self.GetMethodConfig('List')
      return self._RunMethod(
          config, request, global_params=global_params)

    List.method_config = lambda: base_api.ApiMethodInfo(
        flat_path='v1/projects/{projectsId}/locations/global/connectivityTests',
        http_method='GET',
        method_id='networkmanagement.projects.locations.global.connectivityTests.list',
        ordered_params=['parent'],
        path_params=['parent'],
        query_params=['filter', 'orderBy', 'pageSize', 'pageToken'],
        relative_path='v1/{+parent}/connectivityTests',
        request_field='',
        request_type_name='NetworkmanagementProjectsLocationsGlobalConnectivityTestsListRequest',
        response_type_name='ListConnectivityTestsResponse',
        supports_download=False,
    )

    def Patch(self, request, global_params=None):
      r"""Updates the configuration of an existing `ConnectivityTest`. After you update a test, the reachability analysis is performed as part of the long running operation, which completes when the analysis completes. The Reachability state in the test resource is updated with the new result. If the endpoint specifications in `ConnectivityTest` are invalid (for example, they contain non-existent resources in the network, or the user does not have read permissions to the network configurations of listed projects), then the reachability result returns a value of UNKNOWN. If the endpoint specifications in `ConnectivityTest` are incomplete, the reachability result returns a value of `AMBIGUOUS`. See the documentation in `ConnectivityTest` for more details.

      Args:
        request: (NetworkmanagementProjectsLocationsGlobalConnectivityTestsPatchRequest) input message
        global_params: (StandardQueryParameters, default: None) global arguments
      Returns:
        (Operation) The response message.
      """
      config = self.GetMethodConfig('Patch')
      return self._RunMethod(
          config, request, global_params=global_params)

    Patch.method_config = lambda: base_api.ApiMethodInfo(
        flat_path='v1/projects/{projectsId}/locations/global/connectivityTests/{connectivityTestsId}',
        http_method='PATCH',
        method_id='networkmanagement.projects.locations.global.connectivityTests.patch',
        ordered_params=['name'],
        path_params=['name'],
        query_params=['updateMask'],
        relative_path='v1/{+name}',
        request_field='connectivityTest',
        request_type_name='NetworkmanagementProjectsLocationsGlobalConnectivityTestsPatchRequest',
        response_type_name='Operation',
        supports_download=False,
    )

    def Rerun(self, request, global_params=None):
      r"""Rerun an existing `ConnectivityTest`. After the user triggers the rerun, the reachability analysis is performed as part of the long running operation, which completes when the analysis completes. Even though the test configuration remains the same, the reachability result may change due to underlying network configuration changes. If the endpoint specifications in `ConnectivityTest` become invalid (for example, specified resources are deleted in the network, or you lost read permissions to the network configurations of listed projects), then the reachability result returns a value of `UNKNOWN`.

      Args:
        request: (NetworkmanagementProjectsLocationsGlobalConnectivityTestsRerunRequest) input message
        global_params: (StandardQueryParameters, default: None) global arguments
      Returns:
        (Operation) The response message.
      """
      config = self.GetMethodConfig('Rerun')
      return self._RunMethod(
          config, request, global_params=global_params)

    Rerun.method_config = lambda: base_api.ApiMethodInfo(
        flat_path='v1/projects/{projectsId}/locations/global/connectivityTests/{connectivityTestsId}:rerun',
        http_method='POST',
        method_id='networkmanagement.projects.locations.global.connectivityTests.rerun',
        ordered_params=['name'],
        path_params=['name'],
        query_params=[],
        relative_path='v1/{+name}:rerun',
        request_field='rerunConnectivityTestRequest',
        request_type_name='NetworkmanagementProjectsLocationsGlobalConnectivityTestsRerunRequest',
        response_type_name='Operation',
        supports_download=False,
    )

    def SetIamPolicy(self, request, global_params=None):
      r"""Sets the access control policy on the specified resource. Replaces any existing policy. Can return `NOT_FOUND`, `INVALID_ARGUMENT`, and `PERMISSION_DENIED` errors.

      Args:
        request: (NetworkmanagementProjectsLocationsGlobalConnectivityTestsSetIamPolicyRequest) input message
        global_params: (StandardQueryParameters, default: None) global arguments
      Returns:
        (Policy) The response message.
      """
      config = self.GetMethodConfig('SetIamPolicy')
      return self._RunMethod(
          config, request, global_params=global_params)

    SetIamPolicy.method_config = lambda: base_api.ApiMethodInfo(
        flat_path='v1/projects/{projectsId}/locations/global/connectivityTests/{connectivityTestsId}:setIamPolicy',
        http_method='POST',
        method_id='networkmanagement.projects.locations.global.connectivityTests.setIamPolicy',
        ordered_params=['resource'],
        path_params=['resource'],
        query_params=[],
        relative_path='v1/{+resource}:setIamPolicy',
        request_field='setIamPolicyRequest',
        request_type_name='NetworkmanagementProjectsLocationsGlobalConnectivityTestsSetIamPolicyRequest',
        response_type_name='Policy',
        supports_download=False,
    )

    def TestIamPermissions(self, request, global_params=None):
      r"""Returns permissions that a caller has on the specified resource. If the resource does not exist, this will return an empty set of permissions, not a `NOT_FOUND` error. Note: This operation is designed to be used for building permission-aware UIs and command-line tools, not for authorization checking. This operation may "fail open" without warning.

      Args:
        request: (NetworkmanagementProjectsLocationsGlobalConnectivityTestsTestIamPermissionsRequest) input message
        global_params: (StandardQueryParameters, default: None) global arguments
      Returns:
        (TestIamPermissionsResponse) The response message.
      """
      config = self.GetMethodConfig('TestIamPermissions')
      return self._RunMethod(
          config, request, global_params=global_params)

    TestIamPermissions.method_config = lambda: base_api.ApiMethodInfo(
        flat_path='v1/projects/{projectsId}/locations/global/connectivityTests/{connectivityTestsId}:testIamPermissions',
        http_method='POST',
        method_id='networkmanagement.projects.locations.global.connectivityTests.testIamPermissions',
        ordered_params=['resource'],
        path_params=['resource'],
        query_params=[],
        relative_path='v1/{+resource}:testIamPermissions',
        request_field='testIamPermissionsRequest',
        request_type_name='NetworkmanagementProjectsLocationsGlobalConnectivityTestsTestIamPermissionsRequest',
        response_type_name='TestIamPermissionsResponse',
        supports_download=False,
    )

  class ProjectsLocationsGlobalOperationsService(base_api.BaseApiService):
    """Service class for the projects_locations_global_operations resource."""

    _NAME = 'projects_locations_global_operations'

    def __init__(self, client):
      super(NetworkmanagementV1.ProjectsLocationsGlobalOperationsService, self).__init__(client)
      self._upload_configs = {
          }

    def Cancel(self, request, global_params=None):
      r"""Starts asynchronous cancellation on a long-running operation. The server makes a best effort to cancel the operation, but success is not guaranteed. If the server doesn't support this method, it returns `google.rpc.Code.UNIMPLEMENTED`. Clients can use Operations.GetOperation or other methods to check whether the cancellation succeeded or whether the operation completed despite cancellation. On successful cancellation, the operation is not deleted; instead, it becomes an operation with an Operation.error value with a google.rpc.Status.code of `1`, corresponding to `Code.CANCELLED`.

      Args:
        request: (NetworkmanagementProjectsLocationsGlobalOperationsCancelRequest) input message
        global_params: (StandardQueryParameters, default: None) global arguments
      Returns:
        (Empty) The response message.
      """
      config = self.GetMethodConfig('Cancel')
      return self._RunMethod(
          config, request, global_params=global_params)

    Cancel.method_config = lambda: base_api.ApiMethodInfo(
        flat_path='v1/projects/{projectsId}/locations/global/operations/{operationsId}:cancel',
        http_method='POST',
        method_id='networkmanagement.projects.locations.global.operations.cancel',
        ordered_params=['name'],
        path_params=['name'],
        query_params=[],
        relative_path='v1/{+name}:cancel',
        request_field='cancelOperationRequest',
        request_type_name='NetworkmanagementProjectsLocationsGlobalOperationsCancelRequest',
        response_type_name='Empty',
        supports_download=False,
    )

    def Delete(self, request, global_params=None):
      r"""Deletes a long-running operation. This method indicates that the client is no longer interested in the operation result. It does not cancel the operation. If the server doesn't support this method, it returns `google.rpc.Code.UNIMPLEMENTED`.

      Args:
        request: (NetworkmanagementProjectsLocationsGlobalOperationsDeleteRequest) input message
        global_params: (StandardQueryParameters, default: None) global arguments
      Returns:
        (Empty) The response message.
      """
      config = self.GetMethodConfig('Delete')
      return self._RunMethod(
          config, request, global_params=global_params)

    Delete.method_config = lambda: base_api.ApiMethodInfo(
        flat_path='v1/projects/{projectsId}/locations/global/operations/{operationsId}',
        http_method='DELETE',
        method_id='networkmanagement.projects.locations.global.operations.delete',
        ordered_params=['name'],
        path_params=['name'],
        query_params=[],
        relative_path='v1/{+name}',
        request_field='',
        request_type_name='NetworkmanagementProjectsLocationsGlobalOperationsDeleteRequest',
        response_type_name='Empty',
        supports_download=False,
    )

    def Get(self, request, global_params=None):
      r"""Gets the latest state of a long-running operation. Clients can use this method to poll the operation result at intervals as recommended by the API service.

      Args:
        request: (NetworkmanagementProjectsLocationsGlobalOperationsGetRequest) input message
        global_params: (StandardQueryParameters, default: None) global arguments
      Returns:
        (Operation) The response message.
      """
      config = self.GetMethodConfig('Get')
      return self._RunMethod(
          config, request, global_params=global_params)

    Get.method_config = lambda: base_api.ApiMethodInfo(
        flat_path='v1/projects/{projectsId}/locations/global/operations/{operationsId}',
        http_method='GET',
        method_id='networkmanagement.projects.locations.global.operations.get',
        ordered_params=['name'],
        path_params=['name'],
        query_params=[],
        relative_path='v1/{+name}',
        request_field='',
        request_type_name='NetworkmanagementProjectsLocationsGlobalOperationsGetRequest',
        response_type_name='Operation',
        supports_download=False,
    )

    def List(self, request, global_params=None):
      r"""Lists operations that match the specified filter in the request. If the server doesn't support this method, it returns `UNIMPLEMENTED`.

      Args:
        request: (NetworkmanagementProjectsLocationsGlobalOperationsListRequest) input message
        global_params: (StandardQueryParameters, default: None) global arguments
      Returns:
        (ListOperationsResponse) The response message.
      """
      config = self.GetMethodConfig('List')
      return self._RunMethod(
          config, request, global_params=global_params)

    List.method_config = lambda: base_api.ApiMethodInfo(
        flat_path='v1/projects/{projectsId}/locations/global/operations',
        http_method='GET',
        method_id='networkmanagement.projects.locations.global.operations.list',
        ordered_params=['name'],
        path_params=['name'],
        query_params=['filter', 'pageSize', 'pageToken', 'returnPartialSuccess'],
        relative_path='v1/{+name}/operations',
        request_field='',
        request_type_name='NetworkmanagementProjectsLocationsGlobalOperationsListRequest',
        response_type_name='ListOperationsResponse',
        supports_download=False,
    )

  class ProjectsLocationsGlobalService(base_api.BaseApiService):
    """Service class for the projects_locations_global resource."""

    _NAME = 'projects_locations_global'

    def __init__(self, client):
      super(NetworkmanagementV1.ProjectsLocationsGlobalService, self).__init__(client)
      self._upload_configs = {
          }

  class ProjectsLocationsNetworkMonitoringProvidersMonitoringPointsService(base_api.BaseApiService):
    """Service class for the projects_locations_networkMonitoringProviders_monitoringPoints resource."""

    _NAME = 'projects_locations_networkMonitoringProviders_monitoringPoints'

    def __init__(self, client):
      super(NetworkmanagementV1.ProjectsLocationsNetworkMonitoringProvidersMonitoringPointsService, self).__init__(client)
      self._upload_configs = {
          }

    def DownloadInstallScript(self, request, global_params=None):
      r"""Downloads an install script for MonitoringPoints for a given network monitoring provider.

      Args:
        request: (NetworkmanagementProjectsLocationsNetworkMonitoringProvidersMonitoringPointsDownloadInstallScriptRequest) input message
        global_params: (StandardQueryParameters, default: None) global arguments
      Returns:
        (HttpBody) The response message.
      """
      config = self.GetMethodConfig('DownloadInstallScript')
      return self._RunMethod(
          config, request, global_params=global_params)

    DownloadInstallScript.method_config = lambda: base_api.ApiMethodInfo(
        flat_path='v1/projects/{projectsId}/locations/{locationsId}/networkMonitoringProviders/{networkMonitoringProvidersId}/monitoringPoints:downloadInstallScript',
        http_method='GET',
        method_id='networkmanagement.projects.locations.networkMonitoringProviders.monitoringPoints.downloadInstallScript',
        ordered_params=['parent'],
        path_params=['parent'],
        query_params=['_password', 'hostname', 'monitoringPointType', 'ntpServerAddress', 'ntpServerSecondaryAddress', 'privateConnectivityEnabled', 'staticIpAddress_dnsServerAddress', 'staticIpAddress_dnsServerSecondaryAddress', 'staticIpAddress_domain', 'staticIpAddress_gatewayAddress', 'staticIpAddress_ipAddress', 'staticIpAddress_netmask', 'timeZone_id', 'timeZone_version', 'useDhcp'],
        relative_path='v1/{+parent}/monitoringPoints:downloadInstallScript',
        request_field='',
        request_type_name='NetworkmanagementProjectsLocationsNetworkMonitoringProvidersMonitoringPointsDownloadInstallScriptRequest',
        response_type_name='HttpBody',
        supports_download=False,
    )

    def DownloadRecreateInstallScript(self, request, global_params=None):
      r"""Downloads an install script for a specific Container MonitoringPoint.

      Args:
        request: (NetworkmanagementProjectsLocationsNetworkMonitoringProvidersMonitoringPointsDownloadRecreateInstallScriptRequest) input message
        global_params: (StandardQueryParameters, default: None) global arguments
      Returns:
        (HttpBody) The response message.
      """
      config = self.GetMethodConfig('DownloadRecreateInstallScript')
      return self._RunMethod(
          config, request, global_params=global_params)

    DownloadRecreateInstallScript.method_config = lambda: base_api.ApiMethodInfo(
        flat_path='v1/projects/{projectsId}/locations/{locationsId}/networkMonitoringProviders/{networkMonitoringProvidersId}/monitoringPoints/{monitoringPointsId}:downloadRecreateInstallScript',
        http_method='GET',
        method_id='networkmanagement.projects.locations.networkMonitoringProviders.monitoringPoints.downloadRecreateInstallScript',
        ordered_params=['name'],
        path_params=['name'],
        query_params=['hostname'],
        relative_path='v1/{+name}:downloadRecreateInstallScript',
        request_field='',
        request_type_name='NetworkmanagementProjectsLocationsNetworkMonitoringProvidersMonitoringPointsDownloadRecreateInstallScriptRequest',
        response_type_name='HttpBody',
        supports_download=False,
    )

    def DownloadServerConnectConfig(self, request, global_params=None):
      r"""Downloads the server connect configuration for a given network monitoring provider.

      Args:
        request: (NetworkmanagementProjectsLocationsNetworkMonitoringProvidersMonitoringPointsDownloadServerConnectConfigRequest) input message
        global_params: (StandardQueryParameters, default: None) global arguments
      Returns:
        (HttpBody) The response message.
      """
      config = self.GetMethodConfig('DownloadServerConnectConfig')
      return self._RunMethod(
          config, request, global_params=global_params)

    DownloadServerConnectConfig.method_config = lambda: base_api.ApiMethodInfo(
        flat_path='v1/projects/{projectsId}/locations/{locationsId}/networkMonitoringProviders/{networkMonitoringProvidersId}/monitoringPoints:downloadServerConnectConfig',
        http_method='GET',
        method_id='networkmanagement.projects.locations.networkMonitoringProviders.monitoringPoints.downloadServerConnectConfig',
        ordered_params=['parent'],
        path_params=['parent'],
        query_params=[],
        relative_path='v1/{+parent}/monitoringPoints:downloadServerConnectConfig',
        request_field='',
        request_type_name='NetworkmanagementProjectsLocationsNetworkMonitoringProvidersMonitoringPointsDownloadServerConnectConfigRequest',
        response_type_name='HttpBody',
        supports_download=False,
    )

    def Get(self, request, global_params=None):
      r"""Gets the MonitoringPoint resource.

      Args:
        request: (NetworkmanagementProjectsLocationsNetworkMonitoringProvidersMonitoringPointsGetRequest) input message
        global_params: (StandardQueryParameters, default: None) global arguments
      Returns:
        (MonitoringPoint) The response message.
      """
      config = self.GetMethodConfig('Get')
      return self._RunMethod(
          config, request, global_params=global_params)

    Get.method_config = lambda: base_api.ApiMethodInfo(
        flat_path='v1/projects/{projectsId}/locations/{locationsId}/networkMonitoringProviders/{networkMonitoringProvidersId}/monitoringPoints/{monitoringPointsId}',
        http_method='GET',
        method_id='networkmanagement.projects.locations.networkMonitoringProviders.monitoringPoints.get',
        ordered_params=['name'],
        path_params=['name'],
        query_params=[],
        relative_path='v1/{+name}',
        request_field='',
        request_type_name='NetworkmanagementProjectsLocationsNetworkMonitoringProvidersMonitoringPointsGetRequest',
        response_type_name='MonitoringPoint',
        supports_download=False,
    )

    def List(self, request, global_params=None):
      r"""Lists MonitoringPoints for a given network monitoring provider.

      Args:
        request: (NetworkmanagementProjectsLocationsNetworkMonitoringProvidersMonitoringPointsListRequest) input message
        global_params: (StandardQueryParameters, default: None) global arguments
      Returns:
        (ListMonitoringPointsResponse) The response message.
      """
      config = self.GetMethodConfig('List')
      return self._RunMethod(
          config, request, global_params=global_params)

    List.method_config = lambda: base_api.ApiMethodInfo(
        flat_path='v1/projects/{projectsId}/locations/{locationsId}/networkMonitoringProviders/{networkMonitoringProvidersId}/monitoringPoints',
        http_method='GET',
        method_id='networkmanagement.projects.locations.networkMonitoringProviders.monitoringPoints.list',
        ordered_params=['parent'],
        path_params=['parent'],
        query_params=['pageSize', 'pageToken'],
        relative_path='v1/{+parent}/monitoringPoints',
        request_field='',
        request_type_name='NetworkmanagementProjectsLocationsNetworkMonitoringProvidersMonitoringPointsListRequest',
        response_type_name='ListMonitoringPointsResponse',
        supports_download=False,
    )

  class ProjectsLocationsNetworkMonitoringProvidersNetworkPathsService(base_api.BaseApiService):
    """Service class for the projects_locations_networkMonitoringProviders_networkPaths resource."""

    _NAME = 'projects_locations_networkMonitoringProviders_networkPaths'

    def __init__(self, client):
      super(NetworkmanagementV1.ProjectsLocationsNetworkMonitoringProvidersNetworkPathsService, self).__init__(client)
      self._upload_configs = {
          }

    def Get(self, request, global_params=None):
      r"""Gets the NetworkPath resource.

      Args:
        request: (NetworkmanagementProjectsLocationsNetworkMonitoringProvidersNetworkPathsGetRequest) input message
        global_params: (StandardQueryParameters, default: None) global arguments
      Returns:
        (NetworkPath) The response message.
      """
      config = self.GetMethodConfig('Get')
      return self._RunMethod(
          config, request, global_params=global_params)

    Get.method_config = lambda: base_api.ApiMethodInfo(
        flat_path='v1/projects/{projectsId}/locations/{locationsId}/networkMonitoringProviders/{networkMonitoringProvidersId}/networkPaths/{networkPathsId}',
        http_method='GET',
        method_id='networkmanagement.projects.locations.networkMonitoringProviders.networkPaths.get',
        ordered_params=['name'],
        path_params=['name'],
        query_params=[],
        relative_path='v1/{+name}',
        request_field='',
        request_type_name='NetworkmanagementProjectsLocationsNetworkMonitoringProvidersNetworkPathsGetRequest',
        response_type_name='NetworkPath',
        supports_download=False,
    )

    def List(self, request, global_params=None):
      r"""Lists NetworkPaths for a given network monitoring provider.

      Args:
        request: (NetworkmanagementProjectsLocationsNetworkMonitoringProvidersNetworkPathsListRequest) input message
        global_params: (StandardQueryParameters, default: None) global arguments
      Returns:
        (ListNetworkPathsResponse) The response message.
      """
      config = self.GetMethodConfig('List')
      return self._RunMethod(
          config, request, global_params=global_params)

    List.method_config = lambda: base_api.ApiMethodInfo(
        flat_path='v1/projects/{projectsId}/locations/{locationsId}/networkMonitoringProviders/{networkMonitoringProvidersId}/networkPaths',
        http_method='GET',
        method_id='networkmanagement.projects.locations.networkMonitoringProviders.networkPaths.list',
        ordered_params=['parent'],
        path_params=['parent'],
        query_params=['pageSize', 'pageToken'],
        relative_path='v1/{+parent}/networkPaths',
        request_field='',
        request_type_name='NetworkmanagementProjectsLocationsNetworkMonitoringProvidersNetworkPathsListRequest',
        response_type_name='ListNetworkPathsResponse',
        supports_download=False,
    )

  class ProjectsLocationsNetworkMonitoringProvidersWebPathsService(base_api.BaseApiService):
    """Service class for the projects_locations_networkMonitoringProviders_webPaths resource."""

    _NAME = 'projects_locations_networkMonitoringProviders_webPaths'

    def __init__(self, client):
      super(NetworkmanagementV1.ProjectsLocationsNetworkMonitoringProvidersWebPathsService, self).__init__(client)
      self._upload_configs = {
          }

    def Get(self, request, global_params=None):
      r"""Gets the WebPath resource.

      Args:
        request: (NetworkmanagementProjectsLocationsNetworkMonitoringProvidersWebPathsGetRequest) input message
        global_params: (StandardQueryParameters, default: None) global arguments
      Returns:
        (WebPath) The response message.
      """
      config = self.GetMethodConfig('Get')
      return self._RunMethod(
          config, request, global_params=global_params)

    Get.method_config = lambda: base_api.ApiMethodInfo(
        flat_path='v1/projects/{projectsId}/locations/{locationsId}/networkMonitoringProviders/{networkMonitoringProvidersId}/webPaths/{webPathsId}',
        http_method='GET',
        method_id='networkmanagement.projects.locations.networkMonitoringProviders.webPaths.get',
        ordered_params=['name'],
        path_params=['name'],
        query_params=[],
        relative_path='v1/{+name}',
        request_field='',
        request_type_name='NetworkmanagementProjectsLocationsNetworkMonitoringProvidersWebPathsGetRequest',
        response_type_name='WebPath',
        supports_download=False,
    )

    def List(self, request, global_params=None):
      r"""Lists WebPaths for a given network monitoring provider.

      Args:
        request: (NetworkmanagementProjectsLocationsNetworkMonitoringProvidersWebPathsListRequest) input message
        global_params: (StandardQueryParameters, default: None) global arguments
      Returns:
        (ListWebPathsResponse) The response message.
      """
      config = self.GetMethodConfig('List')
      return self._RunMethod(
          config, request, global_params=global_params)

    List.method_config = lambda: base_api.ApiMethodInfo(
        flat_path='v1/projects/{projectsId}/locations/{locationsId}/networkMonitoringProviders/{networkMonitoringProvidersId}/webPaths',
        http_method='GET',
        method_id='networkmanagement.projects.locations.networkMonitoringProviders.webPaths.list',
        ordered_params=['parent'],
        path_params=['parent'],
        query_params=['pageSize', 'pageToken'],
        relative_path='v1/{+parent}/webPaths',
        request_field='',
        request_type_name='NetworkmanagementProjectsLocationsNetworkMonitoringProvidersWebPathsListRequest',
        response_type_name='ListWebPathsResponse',
        supports_download=False,
    )

  class ProjectsLocationsNetworkMonitoringProvidersService(base_api.BaseApiService):
    """Service class for the projects_locations_networkMonitoringProviders resource."""

    _NAME = 'projects_locations_networkMonitoringProviders'

    def __init__(self, client):
      super(NetworkmanagementV1.ProjectsLocationsNetworkMonitoringProvidersService, self).__init__(client)
      self._upload_configs = {
          }

    def Create(self, request, global_params=None):
      r"""Creates a NetworkMonitoringProvider resource.

      Args:
        request: (NetworkmanagementProjectsLocationsNetworkMonitoringProvidersCreateRequest) input message
        global_params: (StandardQueryParameters, default: None) global arguments
      Returns:
        (Operation) The response message.
      """
      config = self.GetMethodConfig('Create')
      return self._RunMethod(
          config, request, global_params=global_params)

    Create.method_config = lambda: base_api.ApiMethodInfo(
        flat_path='v1/projects/{projectsId}/locations/{locationsId}/networkMonitoringProviders',
        http_method='POST',
        method_id='networkmanagement.projects.locations.networkMonitoringProviders.create',
        ordered_params=['parent'],
        path_params=['parent'],
        query_params=['networkMonitoringProviderId'],
        relative_path='v1/{+parent}/networkMonitoringProviders',
        request_field='networkMonitoringProvider',
        request_type_name='NetworkmanagementProjectsLocationsNetworkMonitoringProvidersCreateRequest',
        response_type_name='Operation',
        supports_download=False,
    )

    def Delete(self, request, global_params=None):
      r"""Deletes a NetworkMonitoringProvider resource and all of its child resources.

      Args:
        request: (NetworkmanagementProjectsLocationsNetworkMonitoringProvidersDeleteRequest) input message
        global_params: (StandardQueryParameters, default: None) global arguments
      Returns:
        (Operation) The response message.
      """
      config = self.GetMethodConfig('Delete')
      return self._RunMethod(
          config, request, global_params=global_params)

    Delete.method_config = lambda: base_api.ApiMethodInfo(
        flat_path='v1/projects/{projectsId}/locations/{locationsId}/networkMonitoringProviders/{networkMonitoringProvidersId}',
        http_method='DELETE',
        method_id='networkmanagement.projects.locations.networkMonitoringProviders.delete',
        ordered_params=['name'],
        path_params=['name'],
        query_params=['force'],
        relative_path='v1/{+name}',
        request_field='',
        request_type_name='NetworkmanagementProjectsLocationsNetworkMonitoringProvidersDeleteRequest',
        response_type_name='Operation',
        supports_download=False,
    )

    def GenerateMonitoringPointConfig(self, request, global_params=None):
      r"""Generates Monitoring Point configuration of a NetworkMonitoringProvider resource.

      Args:
        request: (NetworkmanagementProjectsLocationsNetworkMonitoringProvidersGenerateMonitoringPointConfigRequest) input message
        global_params: (StandardQueryParameters, default: None) global arguments
      Returns:
        (GenerateMonitoringPointConfigResponse) The response message.
      """
      config = self.GetMethodConfig('GenerateMonitoringPointConfig')
      return self._RunMethod(
          config, request, global_params=global_params)

    GenerateMonitoringPointConfig.method_config = lambda: base_api.ApiMethodInfo(
        flat_path='v1/projects/{projectsId}/locations/{locationsId}/networkMonitoringProviders/{networkMonitoringProvidersId}:generateMonitoringPointConfig',
        http_method='GET',
        method_id='networkmanagement.projects.locations.networkMonitoringProviders.generateMonitoringPointConfig',
        ordered_params=['name'],
        path_params=['name'],
        query_params=['privateConnectivityEnabled'],
        relative_path='v1/{+name}:generateMonitoringPointConfig',
        request_field='',
        request_type_name='NetworkmanagementProjectsLocationsNetworkMonitoringProvidersGenerateMonitoringPointConfigRequest',
        response_type_name='GenerateMonitoringPointConfigResponse',
        supports_download=False,
    )

    def GenerateProviderAccessToken(self, request, global_params=None):
      r"""Generates a provider access token for a given Google access token. Provider access token is a short-lived token that is used to access resources in the provider's platform.

      Args:
        request: (NetworkmanagementProjectsLocationsNetworkMonitoringProvidersGenerateProviderAccessTokenRequest) input message
        global_params: (StandardQueryParameters, default: None) global arguments
      Returns:
        (GenerateProviderAccessTokenResponse) The response message.
      """
      config = self.GetMethodConfig('GenerateProviderAccessToken')
      return self._RunMethod(
          config, request, global_params=global_params)

    GenerateProviderAccessToken.method_config = lambda: base_api.ApiMethodInfo(
        flat_path='v1/projects/{projectsId}/locations/{locationsId}/networkMonitoringProviders/{networkMonitoringProvidersId}:generateProviderAccessToken',
        http_method='GET',
        method_id='networkmanagement.projects.locations.networkMonitoringProviders.generateProviderAccessToken',
        ordered_params=['name'],
        path_params=['name'],
        query_params=['gcpAccessToken'],
        relative_path='v1/{+name}:generateProviderAccessToken',
        request_field='',
        request_type_name='NetworkmanagementProjectsLocationsNetworkMonitoringProvidersGenerateProviderAccessTokenRequest',
        response_type_name='GenerateProviderAccessTokenResponse',
        supports_download=False,
    )

    def Get(self, request, global_params=None):
      r"""Gets the NetworkMonitoringProvider resource.

      Args:
        request: (NetworkmanagementProjectsLocationsNetworkMonitoringProvidersGetRequest) input message
        global_params: (StandardQueryParameters, default: None) global arguments
      Returns:
        (NetworkMonitoringProvider) The response message.
      """
      config = self.GetMethodConfig('Get')
      return self._RunMethod(
          config, request, global_params=global_params)

    Get.method_config = lambda: base_api.ApiMethodInfo(
        flat_path='v1/projects/{projectsId}/locations/{locationsId}/networkMonitoringProviders/{networkMonitoringProvidersId}',
        http_method='GET',
        method_id='networkmanagement.projects.locations.networkMonitoringProviders.get',
        ordered_params=['name'],
        path_params=['name'],
        query_params=[],
        relative_path='v1/{+name}',
        request_field='',
        request_type_name='NetworkmanagementProjectsLocationsNetworkMonitoringProvidersGetRequest',
        response_type_name='NetworkMonitoringProvider',
        supports_download=False,
    )

    def List(self, request, global_params=None):
      r"""Lists NetworkMonitoringProviders for a given project and location.

      Args:
        request: (NetworkmanagementProjectsLocationsNetworkMonitoringProvidersListRequest) input message
        global_params: (StandardQueryParameters, default: None) global arguments
      Returns:
        (ListNetworkMonitoringProvidersResponse) The response message.
      """
      config = self.GetMethodConfig('List')
      return self._RunMethod(
          config, request, global_params=global_params)

    List.method_config = lambda: base_api.ApiMethodInfo(
        flat_path='v1/projects/{projectsId}/locations/{locationsId}/networkMonitoringProviders',
        http_method='GET',
        method_id='networkmanagement.projects.locations.networkMonitoringProviders.list',
        ordered_params=['parent'],
        path_params=['parent'],
        query_params=['pageSize', 'pageToken'],
        relative_path='v1/{+parent}/networkMonitoringProviders',
        request_field='',
        request_type_name='NetworkmanagementProjectsLocationsNetworkMonitoringProvidersListRequest',
        response_type_name='ListNetworkMonitoringProvidersResponse',
        supports_download=False,
    )

  class ProjectsLocationsVpcFlowLogsConfigsService(base_api.BaseApiService):
    """Service class for the projects_locations_vpcFlowLogsConfigs resource."""

    _NAME = 'projects_locations_vpcFlowLogsConfigs'

    def __init__(self, client):
      super(NetworkmanagementV1.ProjectsLocationsVpcFlowLogsConfigsService, self).__init__(client)
      self._upload_configs = {
          }

    def Create(self, request, global_params=None):
      r"""Creates a new `VpcFlowLogsConfig`. If a configuration with the exact same settings already exists (even if the ID is different), the creation fails. Notes: 1. Creating a configuration with `state=DISABLED` will fail 2. The following fields are not considered as settings for the purpose of the check mentioned above, therefore - creating another configuration with the same fields but different values for the following fields will fail as well: * name * create_time * update_time * labels * description.

      Args:
        request: (NetworkmanagementProjectsLocationsVpcFlowLogsConfigsCreateRequest) input message
        global_params: (StandardQueryParameters, default: None) global arguments
      Returns:
        (Operation) The response message.
      """
      config = self.GetMethodConfig('Create')
      return self._RunMethod(
          config, request, global_params=global_params)

    Create.method_config = lambda: base_api.ApiMethodInfo(
        flat_path='v1/projects/{projectsId}/locations/{locationsId}/vpcFlowLogsConfigs',
        http_method='POST',
        method_id='networkmanagement.projects.locations.vpcFlowLogsConfigs.create',
        ordered_params=['parent'],
        path_params=['parent'],
        query_params=['vpcFlowLogsConfigId'],
        relative_path='v1/{+parent}/vpcFlowLogsConfigs',
        request_field='vpcFlowLogsConfig',
        request_type_name='NetworkmanagementProjectsLocationsVpcFlowLogsConfigsCreateRequest',
        response_type_name='Operation',
        supports_download=False,
    )

    def Delete(self, request, global_params=None):
      r"""Deletes a specific `VpcFlowLogsConfig`.

      Args:
        request: (NetworkmanagementProjectsLocationsVpcFlowLogsConfigsDeleteRequest) input message
        global_params: (StandardQueryParameters, default: None) global arguments
      Returns:
        (Operation) The response message.
      """
      config = self.GetMethodConfig('Delete')
      return self._RunMethod(
          config, request, global_params=global_params)

    Delete.method_config = lambda: base_api.ApiMethodInfo(
        flat_path='v1/projects/{projectsId}/locations/{locationsId}/vpcFlowLogsConfigs/{vpcFlowLogsConfigsId}',
        http_method='DELETE',
        method_id='networkmanagement.projects.locations.vpcFlowLogsConfigs.delete',
        ordered_params=['name'],
        path_params=['name'],
        query_params=[],
        relative_path='v1/{+name}',
        request_field='',
        request_type_name='NetworkmanagementProjectsLocationsVpcFlowLogsConfigsDeleteRequest',
        response_type_name='Operation',
        supports_download=False,
    )

    def Get(self, request, global_params=None):
      r"""Gets the details of a specific `VpcFlowLogsConfig`.

      Args:
        request: (NetworkmanagementProjectsLocationsVpcFlowLogsConfigsGetRequest) input message
        global_params: (StandardQueryParameters, default: None) global arguments
      Returns:
        (VpcFlowLogsConfig) The response message.
      """
      config = self.GetMethodConfig('Get')
      return self._RunMethod(
          config, request, global_params=global_params)

    Get.method_config = lambda: base_api.ApiMethodInfo(
        flat_path='v1/projects/{projectsId}/locations/{locationsId}/vpcFlowLogsConfigs/{vpcFlowLogsConfigsId}',
        http_method='GET',
        method_id='networkmanagement.projects.locations.vpcFlowLogsConfigs.get',
        ordered_params=['name'],
        path_params=['name'],
        query_params=[],
        relative_path='v1/{+name}',
        request_field='',
        request_type_name='NetworkmanagementProjectsLocationsVpcFlowLogsConfigsGetRequest',
        response_type_name='VpcFlowLogsConfig',
        supports_download=False,
    )

    def List(self, request, global_params=None):
      r"""Lists all `VpcFlowLogsConfigs` in a given project.

      Args:
        request: (NetworkmanagementProjectsLocationsVpcFlowLogsConfigsListRequest) input message
        global_params: (StandardQueryParameters, default: None) global arguments
      Returns:
        (ListVpcFlowLogsConfigsResponse) The response message.
      """
      config = self.GetMethodConfig('List')
      return self._RunMethod(
          config, request, global_params=global_params)

    List.method_config = lambda: base_api.ApiMethodInfo(
        flat_path='v1/projects/{projectsId}/locations/{locationsId}/vpcFlowLogsConfigs',
        http_method='GET',
        method_id='networkmanagement.projects.locations.vpcFlowLogsConfigs.list',
        ordered_params=['parent'],
        path_params=['parent'],
        query_params=['filter', 'orderBy', 'pageSize', 'pageToken'],
        relative_path='v1/{+parent}/vpcFlowLogsConfigs',
        request_field='',
        request_type_name='NetworkmanagementProjectsLocationsVpcFlowLogsConfigsListRequest',
        response_type_name='ListVpcFlowLogsConfigsResponse',
        supports_download=False,
    )

    def Patch(self, request, global_params=None):
      r"""Updates an existing `VpcFlowLogsConfig`. If a configuration with the exact same settings already exists (even if the ID is different), the creation fails. Notes: 1. Updating a configuration with `state=DISABLED` will fail. 2. The following fields are not considered as settings for the purpose of the check mentioned above, therefore - updating another configuration with the same fields but different values for the following fields will fail as well: * name * create_time * update_time * labels * description.

      Args:
        request: (NetworkmanagementProjectsLocationsVpcFlowLogsConfigsPatchRequest) input message
        global_params: (StandardQueryParameters, default: None) global arguments
      Returns:
        (Operation) The response message.
      """
      config = self.GetMethodConfig('Patch')
      return self._RunMethod(
          config, request, global_params=global_params)

    Patch.method_config = lambda: base_api.ApiMethodInfo(
        flat_path='v1/projects/{projectsId}/locations/{locationsId}/vpcFlowLogsConfigs/{vpcFlowLogsConfigsId}',
        http_method='PATCH',
        method_id='networkmanagement.projects.locations.vpcFlowLogsConfigs.patch',
        ordered_params=['name'],
        path_params=['name'],
        query_params=['updateMask'],
        relative_path='v1/{+name}',
        request_field='vpcFlowLogsConfig',
        request_type_name='NetworkmanagementProjectsLocationsVpcFlowLogsConfigsPatchRequest',
        response_type_name='Operation',
        supports_download=False,
    )

    def QueryOrgVpcFlowLogsConfigs(self, request, global_params=None):
      r"""QueryOrgVpcFlowLogsConfigs returns a list of all organization-level VPC Flow Logs configurations applicable to the specified project.

      Args:
        request: (NetworkmanagementProjectsLocationsVpcFlowLogsConfigsQueryOrgVpcFlowLogsConfigsRequest) input message
        global_params: (StandardQueryParameters, default: None) global arguments
      Returns:
        (QueryOrgVpcFlowLogsConfigsResponse) The response message.
      """
      config = self.GetMethodConfig('QueryOrgVpcFlowLogsConfigs')
      return self._RunMethod(
          config, request, global_params=global_params)

    QueryOrgVpcFlowLogsConfigs.method_config = lambda: base_api.ApiMethodInfo(
        flat_path='v1/projects/{projectsId}/locations/{locationsId}/vpcFlowLogsConfigs:queryOrgVpcFlowLogsConfigs',
        http_method='GET',
        method_id='networkmanagement.projects.locations.vpcFlowLogsConfigs.queryOrgVpcFlowLogsConfigs',
        ordered_params=['parent'],
        path_params=['parent'],
        query_params=['filter', 'pageSize', 'pageToken'],
        relative_path='v1/{+parent}/vpcFlowLogsConfigs:queryOrgVpcFlowLogsConfigs',
        request_field='',
        request_type_name='NetworkmanagementProjectsLocationsVpcFlowLogsConfigsQueryOrgVpcFlowLogsConfigsRequest',
        response_type_name='QueryOrgVpcFlowLogsConfigsResponse',
        supports_download=False,
    )

    def ShowEffectiveFlowLogsConfigs(self, request, global_params=None):
      r"""ShowEffectiveFlowLogsConfigs returns a list of all VPC Flow Logs configurations applicable to a specified resource.

      Args:
        request: (NetworkmanagementProjectsLocationsVpcFlowLogsConfigsShowEffectiveFlowLogsConfigsRequest) input message
        global_params: (StandardQueryParameters, default: None) global arguments
      Returns:
        (ShowEffectiveFlowLogsConfigsResponse) The response message.
      """
      config = self.GetMethodConfig('ShowEffectiveFlowLogsConfigs')
      return self._RunMethod(
          config, request, global_params=global_params)

    ShowEffectiveFlowLogsConfigs.method_config = lambda: base_api.ApiMethodInfo(
        flat_path='v1/projects/{projectsId}/locations/{locationsId}/vpcFlowLogsConfigs:showEffectiveFlowLogsConfigs',
        http_method='GET',
        method_id='networkmanagement.projects.locations.vpcFlowLogsConfigs.showEffectiveFlowLogsConfigs',
        ordered_params=['parent'],
        path_params=['parent'],
        query_params=['filter', 'pageSize', 'pageToken', 'resource'],
        relative_path='v1/{+parent}/vpcFlowLogsConfigs:showEffectiveFlowLogsConfigs',
        request_field='',
        request_type_name='NetworkmanagementProjectsLocationsVpcFlowLogsConfigsShowEffectiveFlowLogsConfigsRequest',
        response_type_name='ShowEffectiveFlowLogsConfigsResponse',
        supports_download=False,
    )

  class ProjectsLocationsService(base_api.BaseApiService):
    """Service class for the projects_locations resource."""

    _NAME = 'projects_locations'

    def __init__(self, client):
      super(NetworkmanagementV1.ProjectsLocationsService, self).__init__(client)
      self._upload_configs = {
          }

    def Get(self, request, global_params=None):
      r"""Gets information about a location.

      Args:
        request: (NetworkmanagementProjectsLocationsGetRequest) input message
        global_params: (StandardQueryParameters, default: None) global arguments
      Returns:
        (Location) The response message.
      """
      config = self.GetMethodConfig('Get')
      return self._RunMethod(
          config, request, global_params=global_params)

    Get.method_config = lambda: base_api.ApiMethodInfo(
        flat_path='v1/projects/{projectsId}/locations/{locationsId}',
        http_method='GET',
        method_id='networkmanagement.projects.locations.get',
        ordered_params=['name'],
        path_params=['name'],
        query_params=[],
        relative_path='v1/{+name}',
        request_field='',
        request_type_name='NetworkmanagementProjectsLocationsGetRequest',
        response_type_name='Location',
        supports_download=False,
    )

    def List(self, request, global_params=None):
      r"""Lists information about the supported locations for this service. This method lists locations based on the resource scope provided in the ListLocationsRequest.name field: * **Global locations**: If `name` is empty, the method lists the public locations available to all projects. * **Project-specific locations**: If `name` follows the format `projects/{project}`, the method lists locations visible to that specific project. This includes public, private, or other project-specific locations enabled for the project. For gRPC and client library implementations, the resource name is passed as the `name` field. For direct service calls, the resource name is incorporated into the request path based on the specific service implementation and version.

      Args:
        request: (NetworkmanagementProjectsLocationsListRequest) input message
        global_params: (StandardQueryParameters, default: None) global arguments
      Returns:
        (ListLocationsResponse) The response message.
      """
      config = self.GetMethodConfig('List')
      return self._RunMethod(
          config, request, global_params=global_params)

    List.method_config = lambda: base_api.ApiMethodInfo(
        flat_path='v1/projects/{projectsId}/locations',
        http_method='GET',
        method_id='networkmanagement.projects.locations.list',
        ordered_params=['name'],
        path_params=['name'],
        query_params=['extraLocationTypes', 'filter', 'pageSize', 'pageToken'],
        relative_path='v1/{+name}/locations',
        request_field='',
        request_type_name='NetworkmanagementProjectsLocationsListRequest',
        response_type_name='ListLocationsResponse',
        supports_download=False,
    )

  class ProjectsService(base_api.BaseApiService):
    """Service class for the projects resource."""

    _NAME = 'projects'

    def __init__(self, client):
      super(NetworkmanagementV1.ProjectsService, self).__init__(client)
      self._upload_configs = {
          }



# -*- coding: utf-8 -*- #
# Copyright 2026 Google LLC. All Rights Reserved.
#
# Licensed under the Apache License, Version 2.0 (the "License");
# you may not use this file except in compliance with the License.
# You may obtain a copy of the License at
#
#    http://www.apache.org/licenses/LICENSE-2.0
#
# Unless required by applicable law or agreed to in writing, software
# distributed under the License is distributed on an "AS IS" BASIS,
# WITHOUT WARRANTIES OR CONDITIONS OF ANY KIND, either express or implied.
# See the License for the specific language governing permissions and
# limitations under the License.
"""Implementation of gcloud dataflow jobs resume command."""


from googlecloudsdk.api_lib.dataflow import apis
from googlecloudsdk.api_lib.util import exceptions
from googlecloudsdk.calliope import base
from googlecloudsdk.command_lib.dataflow import job_utils
from googlecloudsdk.core import log


@base.ReleaseTracks(base.ReleaseTrack.GA)
@base.DefaultUniverseOnly
@base.Hidden
class Resume(base.Command):
  """Starts resuming all given jobs.

  Once resume is triggered, if eligible, the job will enter the
  `JOB_STATE_RUNNING` state if the operation is successful. If the operation is
  not successful or the job is already running, the job state will be unchanged.
  If a job is already in the `JOB_STATE_RUNNING` state, the command will succeed
  and do nothing.
  """

  @staticmethod
  def Args(parser):
    job_utils.ArgsForJobRefs(parser, nargs='+')

  def Run(self, args):
    for job_ref in job_utils.ExtractJobRefs(args):
      try:
        apis.Jobs.Resume(
            job_ref.jobId,
            project_id=job_ref.projectId,
            region_id=job_ref.location,
        )
        log.status.Print(
            f'Resumed job [{job_ref.jobId}]. Note that the job may take'
            ' several minutes to start processing data again.'
        )
      except exceptions.HttpException as error:
        log.status.Print(
            f'Failed to resume job [{job_ref.jobId}]:'
            f' {error.payload.status_message}'
        )



# -*- coding: utf-8 -*- #
# Copyright 2021 Google Inc. All Rights Reserved.
#
# Licensed under the Apache License, Version 2.0 (the "License");
# you may not use this file except in compliance with the License.
# You may obtain a copy of the License at
#
#    http://www.apache.org/licenses/LICENSE-2.0
#
# Unless required by applicable law or agreed to in writing, software
# distributed under the License is distributed on an "AS IS" BASIS,
# WITHOUT WARRANTIES OR CONDITIONS OF ANY KIND, either express or implied.
# See the License for the specific language governing permissions and
# limitations under the License.
"""Create command for Backup for GKE restore."""


from googlecloudsdk.api_lib.container.backup_restore import util as api_util
from googlecloudsdk.calliope import base
from googlecloudsdk.command_lib.container.backup_restore import hooks
from googlecloudsdk.command_lib.container.backup_restore import resource_args
from googlecloudsdk.command_lib.util.args import labels_util


@base.UniverseCompatible
@base.ReleaseTracks(base.ReleaseTrack.ALPHA, base.ReleaseTrack.BETA)
class Create(base.CreateCommand):
  """Creates a restore.

  Creates a Backup for GKE restore.

  ## EXAMPLES

  To create a restore ``my-restore'' in location ``us-central1'' under restore
  plan ``my-restore-plan'', run:

    $ {command} my-restore --project=my-project --location=us-central1
    --restore-plan=my-restore-plan
    --backup=projects/my-project/locations/us-east1/backupPlans/my-backup-plan/backups/my-backup
  """

  @staticmethod
  def Args(parser):
    resource_args.AddRestoreArg(parser)
    group = parser.add_group(mutex=True)
    group.add_argument(
        '--async',
        required=False,
        action='store_true',
        default=False,
        help="""
        Return immediately, without waiting for the operation in progress to
        complete.
        """,
    )
    group.add_argument(
        '--wait-for-completion',
        required=False,
        action='store_true',
        default=False,
        help='Wait for the created restore to complete.',
    )
    # TODO(b/205222596): Figure out if we can/should use the relative name of
    # the backup. This would potentially require the CLI to first get the backup
    # plan referenced in the parent restore plan and then concat it with the
    # user input relative name.
    parser.add_argument(
        '--backup',
        type=str,
        required=True,
        help="""
        Name of the backup from which to restore under the backup plan specified
        in restore plan.
        Format: projects/<project>/locations/<location>/backupPlans/<backupPlan>/backups/<backup>.
        """,
    )
    parser.add_argument(
        '--description',
        type=str,
        required=False,
        default=None,
        help='Optional text description for the restore.',
    )
    parser.add_argument(
        '--volume-data-restore-policy-overrides-file',
        required=False,
        default=None,
        help="""
        If provided, defines an array of volume data restore policy overrides
        from the given config file in yaml.
        """,
    )
    parser.add_argument(
        '--filter-file',
        required=False,
        default=None,
        help="""
        JSON/YAML file containing the configuration of the fine-grained
        restore filter which can be used to further refine the resource
        selection of the Restore beyond the coarse-grained scope defined
        in the RestorePlan.

        For more information about examples and how to use this filter,
        please refer to the Backup for GKE documentation:
        https://cloud.google.com/kubernetes-engine/docs/add-on/backup-for-gke/how-to/fine-grained-restore.
        """,
    )
    labels_util.AddCreateLabelsFlags(parser)

  def Run(self, args):
    labels = labels_util.GetUpdateLabelsDictFromArgs(args)
    vdrpo = hooks.ReadVolumeDataRestorePolicyOverridesFile(
        args.volume_data_restore_policy_overrides_file
    )
    restore_ref = args.CONCEPTS.restore.Parse()
    restore_filter = hooks.ReadRestoreFilterFile(args.filter_file)
    if args.IsSpecified('async'):
      return api_util.CreateRestore(
          restore_ref,
          backup=args.backup,
          description=args.description,
          labels=labels,
          volume_data_restore_policy_overrides=vdrpo,
          restore_filter=restore_filter,
      )
    api_util.CreateRestoreAndWaitForLRO(
        restore_ref=restore_ref,
        backup=args.backup,
        description=args.description,
        labels=labels,
        volume_data_restore_policy_overrides=vdrpo,
        restore_filter=restore_filter,
    )
    if not args.IsSpecified('wait_for_completion'):
      return []
    return api_util.WaitForRestoreToFinish(restore_ref.RelativeName())



# -*- coding: utf-8 -*- #
# Copyright 2019 Google LLC. All Rights Reserved.
#
# Licensed under the Apache License, Version 2.0 (the "License");
# you may not use this file except in compliance with the License.
# You may obtain a copy of the License at
#
#    http://www.apache.org/licenses/LICENSE-2.0
#
# Unless required by applicable law or agreed to in writing, software
# distributed under the License is distributed on an "AS IS" BASIS,
# WITHOUT WARRANTIES OR CONDITIONS OF ANY KIND, either express or implied.
# See the License for the specific language governing permissions and
# limitations under the License.
"""Surface for creating domain mappings."""


from googlecloudsdk.calliope import base
from googlecloudsdk.command_lib.run import config_changes
from googlecloudsdk.command_lib.run import connection_context
from googlecloudsdk.command_lib.run import deletion
from googlecloudsdk.command_lib.run import domain_mapping_util
from googlecloudsdk.command_lib.run import exceptions
from googlecloudsdk.command_lib.run import flags
from googlecloudsdk.command_lib.run import platforms
from googlecloudsdk.command_lib.run import resource_args
from googlecloudsdk.command_lib.run import serverless_operations
from googlecloudsdk.command_lib.util.concepts import concept_parsers
from googlecloudsdk.command_lib.util.concepts import presentation_specs
from googlecloudsdk.core.console import console_io

DOMAIN_MAPPINGS_HELP_DOCS_URL = ('https://cloud.google.com/run/docs/'
                                 'mapping-custom-domains/')


@base.DefaultUniverseOnly
@base.ReleaseTracks(base.ReleaseTrack.GA)
class Create(base.Command):
  """Create domain mappings for Cloud Run for Anthos."""

  # Hide GA command because only used by Cloud Run for Anthos
  hidden = True

  detailed_help = {
      'DESCRIPTION':
          """\
          {description}

          For domain mapping support with fully managed Cloud Run, use
          `gcloud beta run domain-mappings create`.
          """,
      'EXAMPLES':
          """\
          To create a Cloud Run domain mapping, run:

              $ {command} --service=myapp --domain=www.example.com
          """,
  }

  @staticmethod
  def CommonArgs(parser):
    parser.add_argument(
        '--service', required=True,
        help='Create domain mapping for the given service.')
    domain_mapping_presentation = presentation_specs.ResourcePresentationSpec(
        '--domain',
        resource_args.GetDomainMappingResourceSpec(),
        'Domain name is the ID of DomainMapping resource.',
        required=True,
        prefixes=False)
    parser.add_argument(
        '--force-override',
        action='store_true',
        help='Map this domain even if it is already mapped to another service.'
    )
    concept_parsers.ConceptParser([
        domain_mapping_presentation]).AddToParser(parser)

    parser.display_info.AddFormat(
        """table(
        name:label=NAME,
        type:label="RECORD TYPE",
        rrdata:label=CONTENTS)""")

  @staticmethod
  def Args(parser):
    Create.CommonArgs(parser)

  def VerifyDomain(self, domain_mapping_ref):
    """Verify the domain ownership."""
    # Check if the provided domain has already been verified
    # if mapping to a non-CRoGKE service
    domain_mapping_util.VerifyDomain(domain_mapping_ref)

  def Run(self, args):
    """Create a domain mapping."""
    # domains.cloudrun.com api group only supports v1alpha1 on clusters.
    conn_context = connection_context.GetConnectionContext(
        args,
        flags.Product.RUN,
        self.ReleaseTrack(),
        version_override=('v1alpha1' if
                          platforms.GetPlatform() != platforms.PLATFORM_MANAGED
                          else None))
    domain_mapping_ref = args.CONCEPTS.domain.Parse()
    changes = [
        config_changes.SetLaunchStageAnnotationChange(self.ReleaseTrack())
    ]
    self.VerifyDomain(domain_mapping_ref)

    with serverless_operations.Connect(conn_context) as client:
      try:
        mapping = client.CreateDomainMapping(domain_mapping_ref, args.service,
                                             changes, args.force_override)
      except exceptions.DomainMappingAlreadyExistsError as e:
        if console_io.CanPrompt() and console_io.PromptContinue(
            ('This domain is already being used as a mapping elsewhere. '
             'The existing mapping can be overridden by passing '
             '`--force-override` or by continuing at the prompt below.'),
            prompt_string='Override the existing mapping'):
          deletion.Delete(domain_mapping_ref, client.GetDomainMapping,
                          client.DeleteDomainMapping, async_=False)
          mapping = client.CreateDomainMapping(domain_mapping_ref, args.service,
                                               changes, True)
        else:
          raise e

      for record in mapping.records:
        record.name = record.name or mapping.route_name
      return mapping.records


@base.ReleaseTracks(base.ReleaseTrack.BETA)
class BetaCreate(Create):
  """Create domain mappings."""

  detailed_help = {
      'DESCRIPTION': '{description}',
      'EXAMPLES':
          """\
          To create a Cloud Run domain mapping, run:

              $ {command} --service=myapp --domain=www.example.com
          """,
  }

  @staticmethod
  def Args(parser):
    Create.CommonArgs(parser)


@base.ReleaseTracks(base.ReleaseTrack.ALPHA)
class AlphaCreate(BetaCreate):
  """Create domain mappings."""

  @staticmethod
  def Args(parser):
    Create.CommonArgs(parser)

  def VerifyDomain(self, domain_mapping_ref):
    """Verify the domain ownership. Skip for custom URLs."""
    if not domain_mapping_util.IsCustomUrl(domain_mapping_ref.Name()):
      # Check if the provided domain has already been verified
      # if mapping to a non-CRoGKE service
      domain_mapping_util.VerifyDomain(domain_mapping_ref)



# -*- coding: utf-8 -*- #
# Copyright 2016 Google LLC. All Rights Reserved.
#
# Licensed under the Apache License, Version 2.0 (the "License");
# you may not use this file except in compliance with the License.
# You may obtain a copy of the License at
#
#    http://www.apache.org/licenses/LICENSE-2.0
#
# Unless required by applicable law or agreed to in writing, software
# distributed under the License is distributed on an "AS IS" BASIS,
# WITHOUT WARRANTIES OR CONDITIONS OF ANY KIND, either express or implied.
# See the License for the specific language governing permissions and
# limitations under the License.
"""Delete images command."""


from containerregistry.client import docker_name
from containerregistry.client.v2_2 import docker_session
from googlecloudsdk.api_lib.container.images import util
from googlecloudsdk.calliope import base
from googlecloudsdk.command_lib.container import flags
from googlecloudsdk.core import exceptions
from googlecloudsdk.core import log
from googlecloudsdk.core.console import console_io
from googlecloudsdk.core.resource import resource_printer


class Delete(base.DeleteCommand):
  """Delete existing images.

  The container images delete command of gcloud deletes a specified
  image and tags in a specified repository. Repositories
  must be hosted by the Google Container Registry.
  """

  detailed_help = {
      'DESCRIPTION':
          """\
          The container images delete command deletes the specified image from
          the registry. All associated tags are also deleted.
      """,
      'EXAMPLES':
          """\
          Deletes the image as long as there aren't additional, unspecified tags
          referencing it:

            $ {command} <IMAGE_NAME>

          Deletes the image (and tags) from the input IMAGE_NAME:

            $ {command} <IMAGE_NAME> --force-delete-tags

          Deletes the image (and tags) from the input IMAGE_NAME, without
          additional prompting:

            $ {command} <IMAGE_NAME> --force-delete-tags --quiet

          To easily identify and delete untagged images in a project, first
          filter digests that lack tags:

            $ gcloud container images list-tags [HOSTNAME]/[PROJECT-ID]/[IMAGE]\
              --filter='-tags:*'  --format="get(digest)" --limit=$BIG_NUMBER

          Then, delete these tagless images without prompting by running:

            $ {command} [HOSTNAME]/[PROJECT-ID]/[IMAGE]@DIGEST --quiet

      """,
  }

  @staticmethod
  def Args(parser):
    """Register flags for this command.

    Args:
      parser: An argparse.ArgumentParser-like object. It is mocked out in order
        to capture some information, but behaves like an ArgumentParser.
    """
    flags.AddTagOrDigestPositional(parser, verb='delete')

    parser.add_argument(
        '--force-delete-tags',
        action='store_true',
        default=False,
        help=(
            'If there are tags pointing to an image to be deleted then they '
            'must all be specified explicitly, or this flag must be specified, '
            'for the command to succeed.'))

  def Run(self, args):
    """This is what ts called when the user runs this command.

    Args:
      args: an argparse namespace. All the arguments that were provided to this
        command invocation.

    Raises:
      InvalidImageNameError: If the user specified an invalid image name.
    Returns:
      A list of the deleted docker_name.Tag and docker_name.Digest objects
    """
    # IMAGE_NAME: The fully-qualified image name to delete (with a digest).
    # Deletes the layers. Ex. gcr.io/google-appengine/java(@DIGEST|:TAG).

    http_obj = util.Http()
    with util.WrapExpectedDockerlessErrors():
      # collect input/validate
      digests, explicit_tags = self._ProcessImageNames(args.image_names)

      # Resolve tags to digests.
      for tag in explicit_tags:
        digests.add(util.GetDigestFromName(str(tag)))

      # Find all the tags that reference digests to be deleted.
      all_tags = set()
      for digest in digests:
        all_tags.update(util.GetDockerTagsForDigest(digest, http_obj))

      # Find all the tags that weren't specified explicitly.
      implicit_tags = all_tags.difference(explicit_tags)

      if implicit_tags and not args.force_delete_tags:
        log.error('Tags:')
        for tag in explicit_tags:
          log.error('- ' + str(tag))
        raise exceptions.Error(
            'This operation will implicitly delete the tags listed above. '
            'Please manually remove with the `untag` command or re-run with '
            '--force-delete-tags to confirm.')

      # Print the digests to be deleted.
      if digests:
        log.status.Print('Digests:')
      for digest in digests:
        self._PrintDigest(digest, http_obj)

      # Print the tags to be deleted.
      if explicit_tags:
        log.status.Print('Tags:')
      for tag in explicit_tags:
        log.status.Print('- ' + str(tag))

      # Prompt the user for consent to delete all the above.
      console_io.PromptContinue(
          'This operation will delete the tags and images identified by the '
          'digests above.',
          default=True,
          cancel_on_no=True)

      # The user has given explicit consent, merge the tags.
      explicit_tags.update(implicit_tags)

      # delete and collect output
      result = []
      for tag in explicit_tags:  # tags must be deleted before digests
        self._DeleteDockerTagOrDigest(tag, http_obj)
        result.append({'name': str(tag)})
      for digest in digests:
        self._DeleteDockerTagOrDigest(digest, http_obj)
        result.append({'name': str(digest)})
      return result

  def _ProcessImageNames(self, image_names):
    digests = set()
    tags = set()
    for image_name in image_names:
      docker_obj = util.GetDockerImageFromTagOrDigest(image_name)
      if isinstance(docker_obj, docker_name.Digest):
        digests.add(docker_obj)
      elif isinstance(docker_obj, docker_name.Tag):
        if not util.IsFullySpecified(image_name):
          log.warning('Implicit ":latest" tag specified: ' + image_name)
        tags.add(docker_obj)
    return [digests, tags]

  def _DeleteDockerTagOrDigest(self, tag_or_digest, http_obj):
    docker_session.Delete(
        creds=util.CredentialProvider(), name=tag_or_digest, transport=http_obj)
    log.DeletedResource(tag_or_digest)

  def _PrintDigest(self, digest, http_obj):
    log.status.Print('- ' + str(digest))
    self._DisplayDigestTags(digest, http_obj)

  def _DisplayDigestTags(self, digest, http_obj):
    tag_list = util.GetTagNamesForDigest(digest, http_obj)
    if not tag_list:  # no tags on this digest, skip delete prompt
      return
    fmt = ('list[title="  Associated tags:"]')
    resource_printer.Print(tag_list, fmt, out=log.status)
